==> empathy-2.29.6.tar.bz2: empathy-2.29.6/libempathy-gtk/empathy-spell.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2004-2007 Imendio AB
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * Authors: Martyn Russell <martyn@imendio.com>
 *          Richard Hult <richard@imendio.com>
 */

#ifndef __EMPATHY_SPELL_H__
#define __EMPATHY_SPELL_H__

#include <glib.h>

G_BEGIN_DECLS

gboolean     empathy_spell_supported           (void);
const gchar *empathy_spell_get_language_name   (const gchar *code);
GList       *empathy_spell_get_language_codes  (void);
void         empathy_spell_free_language_codes (GList       *codes);
gboolean     empathy_spell_check               (const gchar *word);
GList *      empathy_spell_get_suggestions     (const gchar *word);
void         empathy_spell_free_suggestions    (GList       *suggestions);

G_END_DECLS

#endif /* __EMPATHY_SPELL_H__ */

==> empathy-2.91.1.tar.bz2: empathy-2.91.1/libempathy-gtk/empathy-spell.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2004-2007 Imendio AB
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * Authors: Martyn Russell <martyn@imendio.com>
 *          Richard Hult <richard@imendio.com>
 */

#ifndef __EMPATHY_SPELL_H__
#define __EMPATHY_SPELL_H__

#include <glib.h>

G_BEGIN_DECLS

gboolean     empathy_spell_supported           (void);
const gchar *empathy_spell_get_language_name   (const gchar *code);
GList       *empathy_spell_get_language_codes  (void);
GList       *empathy_spell_get_enabled_language_codes (void);
void         empathy_spell_free_language_codes (GList       *codes);
gboolean     empathy_spell_check               (const gchar *word);
GList *      empathy_spell_get_suggestions     (const gchar *code,
						const gchar *word);
void         empathy_spell_free_suggestions    (GList       *suggestions);

G_END_DECLS

#endif /* __EMPATHY_SPELL_H__ */
